Atramhasis
==========

.. image:: https://travis-ci.org/OnroerendErfgoed/atramhasis.png?branch=master
        :target: https://travis-ci.org/OnroerendErfgoed/atramhasis
.. image:: https://coveralls.io/repos/OnroerendErfgoed/atramhasis/badge.png?branch=master
        :target: https://coveralls.io/r/OnroerendErfgoed/atramhasis
.. image:: https://badge.fury.io/py/atramhasis.png
        :target: http://badge.fury.io/py/atramhasis

Atramhasis aims to be an online SKOS editor. This webapplication will enable
users to create SKOS vocabularies, concepts and collections.
